GenomeServiceImpl

Struct GenomeServiceImpl 

pub struct GenomeServiceImpl { /* private fields */ }
Default implementation of GenomeService

Implementations

Source

impl GenomeServiceImpl

pub fn new(connectome: Arc<RwLock<ConnectomeManager>>) -> Self

pub fn new_with_parameter_queue( connectome: Arc<RwLock<ConnectomeManager>>, parameter_queue: ParameterUpdateQueue, ) -> Self

pub fn set_burst_runner(&mut self, burst_runner: Arc<RwLock<BurstLoopRunner>>)

Set the burst runner for cache refresh

pub fn get_current_genome_arc(&self) -> Arc<RwLock<Option<RuntimeGenome>>>

Get a reference to the current genome Arc This allows other services to share access to the genome for persistence