pub struct GenomeServiceImpl { /* private fields */ }Expand description
Default implementation of GenomeService
Implementations
Sourceimpl GenomeServiceImpl
impl GenomeServiceImpl
pub fn new(connectome: Arc<RwLock<ConnectomeManager>>) -> Self
pub fn new_with_parameter_queue( connectome: Arc<RwLock<ConnectomeManager>>, parameter_queue: ParameterUpdateQueue, ) -> Self
Sourcepub fn set_burst_runner(&mut self, burst_runner: Arc<RwLock<BurstLoopRunner>>)
pub fn set_burst_runner(&mut self, burst_runner: Arc<RwLock<BurstLoopRunner>>)
Set the burst runner for cache refresh
Sourcepub fn get_current_genome_arc(&self) -> Arc<RwLock<Option<RuntimeGenome>>>
pub fn get_current_genome_arc(&self) -> Arc<RwLock<Option<RuntimeGenome>>>
Get a reference to the current genome Arc This allows other services to share access to the genome for persistence